var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Injectable } from '@nestjs/common';
import { Tags } from 'opentracing';
import { RequestSpanService } from './request-span.service';
import { RequestContext } from './request-context';
import { markAsErroredSpan, SpanService } from './span.service';
import { TracerService } from './tracer.service';
let JaegerMiddleware = class JaegerMiddleware {
    constructor(tracerService, spanService, requestContext, requestSpan) {
        this.tracerService = tracerService;
        this.spanService = spanService;
        this.requestContext = requestContext;
        this.requestSpan = requestSpan;
    }
    use(req, res, next) {
        this.requestContext.run(() => {
            const parentSpanContext = this.tracerService.extractSpanFromHeaders(req.headers);
            const url = req.path != '/' ? req.baseUrl + req.path : req.baseUrl;
            const span = this.spanService.startActiveSpan(url, {
                childOf: parentSpanContext,
                tags: {
                    [Tags.SPAN_KIND]: Tags.SPAN_KIND_MESSAGING_PRODUCER,
                    [Tags.HTTP_METHOD]: req.method,
                    [Tags.HTTP_URL]: url
                }
            });
            this.requestSpan.set(span);
            res.once('finish', () => {
                span.setTag(Tags.HTTP_STATUS_CODE, res.statusCode);
                if (res.statusCode >= 500) {
                    markAsErroredSpan(span);
                }
                this.spanService.finishSpan(span);
            });
            next();
        });
    }
};
JaegerMiddleware = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [TracerService,
        SpanService,
        RequestContext,
        RequestSpanService])
], JaegerMiddleware);
export { JaegerMiddleware };
