var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Injectable } from '@nestjs/common';
import { Tags } from 'opentracing';
import { RequestContext } from './request-context';
import { TracerService } from './tracer.service';
const SPAN_ERROR = Symbol('SPAN_ERROR');
export const ACTIVE_SPAN = Symbol('ACTIVE_SPAN');
let SpanService = class SpanService {
    constructor(tracerService, requestContext) {
        this.tracerService = tracerService;
        this.requestContext = requestContext;
    }
    /** Start a new span */
    startSpan(name, options) {
        return this.tracerService.getTracer().startSpan(name, options);
    }
    /** Start a new span and set it as the active span */
    startActiveSpan(name, options) {
        const span = this.startSpan(name, options);
        this.requestContext.set(ACTIVE_SPAN, span);
        return span;
    }
    /** Finalizes the given span. If the span is the active span it is also unset */
    finishSpan(span) {
        span.finish();
        const activeSpan = this.getActiveSpan();
        if (span === activeSpan) {
            this.requestContext.delete(ACTIVE_SPAN);
        }
    }
    /** Get the active span. If there is no active span it returns `undefined` */
    getActiveSpan() {
        return this.requestContext.get(ACTIVE_SPAN);
    }
    /**
     * Run the given handler for an span context.
     * When the handler is finished the span is also automatically finished
     */
    async withSpan({ name, active = false, options, handler }) {
        const span = active ? this.startActiveSpan(name, options) : this.startSpan(name, options);
        try {
            return await handler(span);
        }
        finally {
            this.finishSpan(span);
        }
    }
};
SpanService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [TracerService, RequestContext])
], SpanService);
export { SpanService };
/** Check if the given span has been marked as error  */
export function isErroredSpan(span) {
    return span[SPAN_ERROR] === true;
}
/**
 * Marks the span as error span.
 * Use this instead of `span.setTag('error', true)` because it only will not set the error tag more than once
 */
export function markAsErroredSpan(span) {
    if (isErroredSpan(span)) {
        return;
    }
    span[SPAN_ERROR] = true;
    span.setTag(Tags.ERROR, true);
}
