import format from 'quick-format-unescaped';
import { markAsErroredSpan } from '../jaeger/span.service';
export class SpanLogger {
    constructor(logger, getSpan) {
        this.logger = logger;
        this.getSpan = getSpan;
    }
    fatal(msg, ...args) {
        this.log('fatal', msg, ...args);
    }
    error(msg, ...args) {
        this.log('error', msg, ...args);
    }
    warn(msg, ...args) {
        this.log('warn', msg, ...args);
    }
    info(msg, ...args) {
        this.log('info', msg, ...args);
    }
    debug(msg, ...args) {
        this.log('debug', msg, ...args);
    }
    log(level, message, ...args) {
        this.logger[level](message, ...args);
        this.logToSpan(level, message, args);
    }
    logToSpan(level, message, ...args) {
        const span = this.getSpan();
        if (!span) {
            return;
        }
        const isError = level === 'error' || level === 'fatal';
        if (isError) {
            markAsErroredSpan(span);
        }
        let meta = undefined;
        if (typeof message !== 'string') {
            meta = message;
            message = args[0];
            args = args.slice(1);
        }
        const log = {
            event: isError ? 'error' : 'log',
            'log.level': level,
            message: format(message, args)
        };
        if (meta && Object.keys(meta).length > 0) {
            log.metadata = meta;
        }
        span.log(log);
    }
}
