"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.JaegerMiddleware = void 0;
const common_1 = require("@nestjs/common");
const opentracing_1 = require("opentracing");
const request_span_service_1 = require("./request-span.service");
const request_context_1 = require("./request-context");
const span_service_1 = require("./span.service");
const tracer_service_1 = require("./tracer.service");
let JaegerMiddleware = class JaegerMiddleware {
    constructor(tracerService, spanService, requestContext, requestSpan) {
        this.tracerService = tracerService;
        this.spanService = spanService;
        this.requestContext = requestContext;
        this.requestSpan = requestSpan;
    }
    use(req, res, next) {
        this.requestContext.run(() => {
            const parentSpanContext = this.tracerService.extractSpanFromHeaders(req.headers);
            const url = req.path != '/' ? req.baseUrl + req.path : req.baseUrl;
            const span = this.spanService.startActiveSpan(url, {
                childOf: parentSpanContext,
                tags: {
                    [opentracing_1.Tags.SPAN_KIND]: opentracing_1.Tags.SPAN_KIND_MESSAGING_PRODUCER,
                    [opentracing_1.Tags.HTTP_METHOD]: req.method,
                    [opentracing_1.Tags.HTTP_URL]: url
                }
            });
            this.requestSpan.set(span);
            res.once('finish', () => {
                span.setTag(opentracing_1.Tags.HTTP_STATUS_CODE, res.statusCode);
                if (res.statusCode >= 500) {
                    (0, span_service_1.markAsErroredSpan)(span);
                }
                this.spanService.finishSpan(span);
            });
            next();
        });
    }
};
exports.JaegerMiddleware = JaegerMiddleware;
exports.JaegerMiddleware = JaegerMiddleware = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [tracer_service_1.TracerService,
        span_service_1.SpanService,
        request_context_1.RequestContext,
        request_span_service_1.RequestSpanService])
], JaegerMiddleware);
