import { Span, SpanOptions } from 'opentracing';
import { RequestContext } from './request-context';
import { TracerService } from './tracer.service';
export declare const ACTIVE_SPAN: unique symbol;
export declare class SpanService {
    private readonly tracerService;
    private readonly requestContext;
    constructor(tracerService: TracerService, requestContext: RequestContext);
    /** Start a new span */
    startSpan(name: string, options?: SpanOptions): Span;
    /** Start a new span and set it as the active span */
    startActiveSpan(name: string, options?: SpanOptions): Span;
    /** Finalizes the given span. If the span is the active span it is also unset */
    finishSpan(span: Span): void;
    /** Get the active span. If there is no active span it returns `undefined` */
    getActiveSpan(): Span | undefined;
    /**
     * Run the given handler for an span context.
     * When the handler is finished the span is also automatically finished
     */
    withSpan<R>({ name, active, options, handler }: WithSpanOptions<R>): Promise<R>;
}
export interface WithSpanOptions<R = unknown> {
    name: string;
    handler: (span: Span) => R;
    active?: boolean;
    options?: SpanOptions;
}
/** Check if the given span has been marked as error  */
export declare function isErroredSpan(span: Span): boolean;
/**
 * Marks the span as error span.
 * Use this instead of `span.setTag('error', true)` because it only will not set the error tag more than once
 */
export declare function markAsErroredSpan(span: Span): void;
