/// <reference types="node" />
import { OnModuleDestroy, OnModuleInit } from '@nestjs/common';
import { IncomingHttpHeaders } from 'http';
import { JaegerTracer } from 'jaeger-client';
import { SpanContext } from 'opentracing';
import { TracerConfiguration } from './jaeger.module';
export declare class TracerService implements OnModuleInit, OnModuleDestroy {
    private readonly configuration;
    private tracer?;
    constructor(configuration: TracerConfiguration);
    /**
     * Get the tracer. If the tracer is not yet initialized it throws a {@link TracerInitializationError}
     */
    getTracer(): JaegerTracer;
    /** Extract the span context from the request headers */
    extractSpanFromHeaders(headers: IncomingHttpHeaders): SpanContext | undefined;
    /** Initialize the Jaeger tracer. It can only by initialized once son multiple calls will have no effect */
    onModuleInit(): void;
    /** Close the current tracer */
    onModuleDestroy(): Promise<void>;
}
