"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TracerService = void 0;
const common_1 = require("@nestjs/common");
const jaeger_client_1 = require("jaeger-client");
const opentracing_1 = require("opentracing");
const tracer_initialization_error_1 = require("./tracer-initialization.error");
const tracer_keys_1 = require("./tracer.keys");
let TracerService = class TracerService {
    constructor(configuration) {
        this.configuration = configuration;
    }
    /**
     * Get the tracer. If the tracer is not yet initialized it throws a {@link TracerInitializationError}
     */
    getTracer() {
        if (!this.tracer) {
            throw new tracer_initialization_error_1.TracerInitializationError();
        }
        return this.tracer;
    }
    /** Extract the span context from the request headers */
    extractSpanFromHeaders(headers) {
        return this.getTracer().extract(opentracing_1.FORMAT_HTTP_HEADERS, headers) ?? undefined;
    }
    /** Initialize the Jaeger tracer. It can only by initialized once son multiple calls will have no effect */
    onModuleInit() {
        if (this.tracer) {
            return;
        }
        const { config = {}, options = {} } = this.configuration;
        this.tracer = (0, jaeger_client_1.initTracer)(config, options);
    }
    /** Close the current tracer */
    async onModuleDestroy() {
        // Also check the close function because it does not exist in the noop tracer
        // which is the tracer we get when config.disable is set to true
        await new Promise(resolve => this.tracer?.close?.(resolve) ?? resolve());
        this.tracer = undefined;
    }
};
exports.TracerService = TracerService;
exports.TracerService = TracerService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, tracer_keys_1.InjectTracerOptions)()),
    __metadata("design:paramtypes", [Object])
], TracerService);
