"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SpanLogger = void 0;
const quick_format_unescaped_1 = __importDefault(require("quick-format-unescaped"));
const span_service_1 = require("../jaeger/span.service");
class SpanLogger {
    constructor(logger, getSpan) {
        this.logger = logger;
        this.getSpan = getSpan;
    }
    fatal(msg, ...args) {
        this.log('fatal', msg, ...args);
    }
    error(msg, ...args) {
        this.log('error', msg, ...args);
    }
    warn(msg, ...args) {
        this.log('warn', msg, ...args);
    }
    info(msg, ...args) {
        this.log('info', msg, ...args);
    }
    debug(msg, ...args) {
        this.log('debug', msg, ...args);
    }
    log(level, message, ...args) {
        this.logger[level](message, ...args);
        this.logToSpan(level, message, args);
    }
    logToSpan(level, message, ...args) {
        const span = this.getSpan();
        if (!span) {
            return;
        }
        const isError = level === 'error' || level === 'fatal';
        if (isError) {
            (0, span_service_1.markAsErroredSpan)(span);
        }
        let meta = undefined;
        if (typeof message !== 'string') {
            meta = message;
            message = args[0];
            args = args.slice(1);
        }
        const log = {
            event: isError ? 'error' : 'log',
            'log.level': level,
            message: (0, quick_format_unescaped_1.default)(message, args)
        };
        if (meta && Object.keys(meta).length > 0) {
            log.metadata = meta;
        }
        span.log(log);
    }
}
exports.SpanLogger = SpanLogger;
